//+------------------------------------------------------------------+
//|                                                    MultiMove.mq4 |
//+------------------------------------------------------------------+
#property copyright "Copyright  2012, TheXpert"
#property link      "mqltech@gmail.com"

#property indicator_separate_window

#property indicator_buffers 5

#property indicator_color1 Red
#property indicator_color2 Red
#property indicator_color3 Red
#property indicator_color4 Red
#property indicator_color5 Red

extern string  Instrument = "";
extern int     Number = 1;
extern int     Overall = 1;
extern double  PercentScale = 1;

extern color   ShadowColor = DarkGray;
extern color   BodyColor = Green;

double Hi[];
double Lo[];
double Cl[];
double FakeMin[];
double FakeMax[];

double FMin, FMax;

int init()
{
   if (Instrument == "") Instrument = Symbol();
   
   SetIndexBuffer(0, FakeMin);
   SetIndexBuffer(1, FakeMax);
   SetIndexBuffer(2, Hi);
   SetIndexBuffer(3, Lo);
   SetIndexBuffer(4, Cl);

   SetIndexStyle(0, DRAW_NONE, EMPTY, 1, CLR_NONE);
   SetIndexStyle(1, DRAW_NONE, EMPTY, 1, CLR_NONE);
   
   SetIndexStyle(2, DRAW_HISTOGRAM, EMPTY, 1, ShadowColor);
   SetIndexStyle(3, DRAW_HISTOGRAM, EMPTY, 1, ShadowColor);
   SetIndexStyle(4, DRAW_HISTOGRAM, EMPTY, 4, BodyColor);
   
   SetLevelValue(0, 0);
   
   SetIndexEmptyValue(0, 0);
   SetIndexEmptyValue(1, 0);
   SetIndexEmptyValue(2, 0);
   SetIndexEmptyValue(3, 0);
   SetIndexEmptyValue(4, 0);
   
   IndicatorDigits(3);
   
   string name = "Multi for " + Instrument;
   
   IndicatorShortName(name);
   
   SetIndexLabel(0, name);
   SetIndexLabel(1, name);
   SetIndexLabel(2, name);
   SetIndexLabel(3, name);
   SetIndexLabel(4, name);
   
   if (Overall > 1)
   {
      FMin = 2*Number - 2*Overall - 2;
      FMax = 2*Number;
   }
   else
   {
      FMin = 0;
      FMax = 0;
   }
   
   return(0);
}

int start()
{
   int toCount = MathMin(Bars, Bars - IndicatorCounted());
   
   for (int i = 0; i < toCount; i++)
   {
      int pos = iBarShift(Instrument, Period(), Time[i], true);
      if (pos == -1)
      {
         Hi[i] = 0;
         Lo[i] = 0;
         Cl[i] = 0;
         FakeMax[i] = FMax;
         FakeMin[i] = FMin;
         continue;
      }
      
      double h = iHigh(Instrument, Period(), pos);
      double l = iLow(Instrument, Period(), pos);
      double o = iOpen(Instrument, Period(), pos);
      double c = iClose(Instrument, Period(), pos);
      
      if (Overall > 1)
      {
         Hi[i] = MathMin((h - o)/o*100, FMax);
         Lo[i] = MathMax((l - o)/l*100, FMin);
         Cl[i] = MathMax(MathMin((c - o)/o*100, FMax), FMin);
      }
      else
      {
         Hi[i] = (h - o)/o*100;
         Lo[i] = (l - o)/l*100;
         Cl[i] = (c - o)/o*100;
      }
      
      FakeMax[i] = FMax;
      FakeMin[i] = FMin;
   }
   
   return(0);
}